import jaraco.windows.clipboard as wclip

copy_text = wclip.set_unicode_text
paste_text = wclip.get_unicode_text

copy_html = wclip.set_html

def paste_html():
	wclip.get_html().html

paste_image = wclip.get_image



import functools

import richxerox

paste_text = richxerox.paste
copy_text = richxerox.copy

paste_html = functools.partial(richxerox.paste, format='html')
copy_html = functools.partial(richxerox.copy, format='html')
